Data Access
===========

Geo2Grid software is designed with the direct broadcast community
in mind as the target end user.  However, the software can be used
by anyone to create images from standard mission compliant input
files. NOAA GOES ABI data is now freely available from Cloud
Service Providers (CSPs) including Amazon Web Services (AWS),
Google and Microsoft Azure.  More information about accessing
data that is part of NOAA's Open Data Dissemination Program
can be found at this website:

    https://www.noaa.gov/nodd/datasets

And a very nice interface that allows direct downloads from
the AWS can be found here:

    http://home.chpc.utah.edu/~u0553130/Brian_Blaylock/cgi-bin/goes16_download.cgi
